
#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */
#include "LIB_LCD.h"

// Freescale Logo

#define SEG_LOGO 0x80                              

// Low Byte Segments Mask Definition

#define SEG_A 0x0001
#define SEG_H 0x0002
#define SEG_F 0x0004
#define SEG_G 0x0008
#define SEG_E 0x0010
#define SEG_N 0x0020

// High Byte Segments Mask Definition

#define SEG_J 0x0100
#define SEG_K 0x0200
#define SEG_B 0x0400
#define SEG_C 0x0800
#define SEG_L 0x1000
#define SEG_M 0x2000
#define SEG_D 0x4000

// Message Characters Definition

// DEMO9RS08LA8

// Low Byte Definition

#define CHAR_0  (SEG_A | SEG_B | SEG_C | SEG_D | SEG_E | SEG_F) // ABCDEF

#define CHAR_1  (SEG_B | SEG_C) // BC

#define CHAR_2  (SEG_A | SEG_B | SEG_D | SEG_E | SEG_G) // ABDEG

#define CHAR_3  (SEG_A | SEG_B | SEG_C | SEG_D | SEG_G) // ABCDG

#define CHAR_4  (SEG_B | SEG_C | SEG_F | SEG_G) // BCFG

#define CHAR_5  (SEG_A | SEG_C | SEG_D | SEG_F | SEG_G) // ACDFG

#define CHAR_6  (SEG_A | SEG_C | SEG_D | SEG_E | SEG_F | SEG_G)// ACDEFG

#define CHAR_7  (SEG_A | SEG_B | SEG_C) // ABC

#define CHAR_8  (SEG_A | SEG_B | SEG_C | SEG_D | SEG_E | SEG_F | SEG_G) // ABCDEFG

#define CHAR_9  (SEG_A | SEG_B | SEG_C | SEG_D | SEG_F | SEG_G) // ABCDFG

#define CHAR_M  (SEG_B | SEG_C | SEG_E | SEG_F | SEG_H | SEG_K) // BCEFHK

#define CHAR_C  (SEG_A | SEG_D | SEG_E | SEG_F) // ADEF

#define CHAR_R  (SEG_A | SEG_B | SEG_E | SEG_F | SEG_G | SEG_L) // ABEFGL

#define CHAR_S  (SEG_A | SEG_C | SEG_D | SEG_F | SEG_G)// ACDFG

#define CHAR_L  (SEG_D | SEG_E | SEG_F) // DEF

#define CHAR_A  (SEG_A | SEG_B | SEG_C | SEG_E | SEG_F | SEG_G) // ABCEFG

#define CHAR_D  (SEG_B | SEG_C | SEG_D | SEG_E | SEG_G) // BCDEG

#define CHAR_E  (SEG_A | SEG_D | SEG_E | SEG_F | SEG_G) // ADEFG

#define CHAR_O  (SEG_A | SEG_B | SEG_C | SEG_D | SEG_E | SEG_F) // ABCDEF

#define CHAR_B  (SEG_C | SEG_D | SEG_E | SEG_F | SEG_G) // CDEFG

unsigned short digit[10] = {
  CHAR_0, CHAR_1, CHAR_2, CHAR_3, CHAR_4,
  CHAR_5, CHAR_6, CHAR_7, CHAR_8, CHAR_9
};

unsigned short Message[30] @0x80 = {
  CHAR_M, CHAR_C, CHAR_9, CHAR_R, CHAR_S, CHAR_0,
  CHAR_8, CHAR_L, CHAR_A, CHAR_8, 0,      CHAR_D,
  CHAR_E, CHAR_M, CHAR_O, 0,      CHAR_B, CHAR_O,
  CHAR_A, CHAR_R, CHAR_D, 0,      0,      0,
  0,      0,      0,      0,      0,      0
};

unsigned char iMsg;
unsigned char second;
unsigned char minute;
unsigned char hour;
unsigned char dot;

#pragma INLINE

void LCD_init(void) {

  unsigned char i;
  
  unsigned char *p;

  iMsg = 0;
  
  LCDC0_LCDEN = 0;
  
  LCDC0 = LCDC0_SOURCE_MASK | LCDC0_LCLK0_MASK | LCDC0_DUTY_MASK;
  
  LCDC1 = LCDC1_FCDEN_MASK;
  
  LCDSUPPLY = LCDSUPPLY_VSUPPLY0_MASK;
  
  LCDBCTL = 0;

  LCDPEN0 = 0xFF;
  LCDPEN1 = 0xFF;
  LCDPEN2 = 0xFF;
  LCDPEN3 = 0x1F;
  
  LCDBPEN0 = 0x80;
  LCDBPEN1 = 0x7F;
  LCDBPEN2 = 0x00;
  LCDBPEN3 = 0x00;
  
  p = (char *)0x20;
  
  for (i = 0; i < 29; i++) {
    *p++ = 0x00;
  }
  
  LCDWF7 = 0x80;
  LCDWF8 = 0x40;
  LCDWF9 = 0x20;
  LCDWF10 = 0x10;
  LCDWF11 = 0x08;
  LCDWF12 = 0x04;
  LCDWF13 = 0x02;
  LCDWF14 = 0x01;
    
  LCDC0_LCDEN = 1;
  
  second = 0;
  minute = 0;
  hour = 0;
  dot = 0;
}

void Tick(void) {

  dot ^= 0x80;
  
  second++;
  
  if (second >= 60) {
    second = 0;
    minute++;
  }
  
  if (minute >= 60) {
    minute = 0;
    hour++;
  }
  
  if (hour >= 24) {
    hour = 0;
  }
  
  return;
}

void DisplayTime(void) {

  unsigned char i;
  
  LCDWF6  = 0;
  LCDWF16 = SEG_LOGO;
  
  LCDWF5  = 0;
  LCDWF17 = 0;
  
  LCDWF4  = 0;
  LCDWF18 = 0;
  
  i = hour / 10;
  
  LCDWF3  = digit[i] >> 8;
  LCDWF19 = digit[i] & 0xFF;
  
  i = hour % 10;

  LCDWF2  = digit[i] >> 8;
  LCDWF20 = digit[i] & 0xFF;
  
  i = minute / 10;

  LCDWF1  = digit[i] >> 8;
  LCDWF21 = digit[i] & 0xFF | dot;
  
  i = minute % 10;

  LCDWF0  = digit[i] >> 8;
  LCDWF22 = digit[i] & 0xFF;
  
  i = second / 10;

  LCDWF28 = digit[i] >> 8;
  LCDWF23 = digit[i] & 0xFF | dot;
  
  i = second % 10;

  LCDWF27 = digit[i] >> 8;
  LCDWF24 = digit[i] & 0xFF;
  
  return;
}

void DisplayMessage(void) {

  unsigned char * q = (void *)(Message + iMsg);
  
  iMsg++;
  
  if (iMsg >= 21) {
     iMsg = 0;
  }

  LCDWF6  = *q++;
  LCDWF16 = (*q++) | SEG_LOGO;
  
  LCDWF5  = *q++;
  LCDWF17 = *q++;
  
  LCDWF4  = *q++;
  LCDWF18 = *q++;

  LCDWF3  = *q++;
  LCDWF19 = *q++;

  LCDWF2  = *q++;
  LCDWF20 = *q++;

  LCDWF1  = *q++;
  LCDWF21 = *q++;

  LCDWF0  = *q++;
  LCDWF22 = *q++;

  LCDWF28 = *q++;
  LCDWF23 = *q++;

  LCDWF27 = *q++;
  LCDWF24 = *q++;
  
  return;
}















